==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/it.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Aggiunto all'elenco dei server affidabili",
    "No server found with ID: %s" : "Nessun server trovato con il seguete ID: %s",
    "Could not remove server" : "Impossibile rimuovere il server",
    "Server is already in the list of trusted servers." : "Il server è già nell'elenco dei server affidabili.",
    "No server to federate with found" : "Non ho trovato alcun server per la federazione",
    "Could not add server" : "Impossibile aggiungere il server",
    "Trusted servers" : "Server affidabili",
    "Federation" : "Federazione",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "La federazione consente di connettersi ad altri server attendibili per scambiare la directory degli account.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "La federazione consente di connettersi ad altri server attendibili per scambiare la directory degli account. Ad esempio, questo verrà utilizzato per completare automaticamente gli account esterni per la condivisione federata.",
    "External documentation for Federated Cloud Sharing" : "Documentazione esterna per la Condivisione Federata",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La federazione consente di connettersi ad altri server attendibili per scambiare la directory degli account. Ad esempio, questo verrà utilizzato per completare automaticamente gli account esterni per la condivisione federata. Non è necessario aggiungere un server come server attendibile per creare una condivisione federata.",
    "Each server must validate the other. This process may require a few cron cycles." : "Ogni server deve validare gli altri. Questa operazione può richiedere qualche ciclo cron.",
    "+ Add trusted server" : "+ Aggiungi server affidabile",
    "Trusted server" : "Server affidabile",
    "Add" : "Aggiungi"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/it.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Aggiunto all'elenco dei server affidabili",
    "No server found with ID: %s" : "Nessun server trovato con il seguente ID: %s",
    "Could not remove server" : "Impossibile rimuovere il server",
    "Server is already in the list of trusted servers." : "Il server è già nell'elenco dei server affidabili.",
    "No server to federate with found" : "Non ho trovato alcun server per la federazione",
    "Could not add server" : "Impossibile aggiungere il server",
    "Trusted servers" : "Server affidabili",
    "Federation" : "Federazione",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "La federazione consente di connettersi ad altri server attendibili per scambiare la directory degli account.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "La federazione consente di connettersi ad altri server attendibili per scambiare la directory degli account. Ad esempio, questo verrà utilizzato per completare automaticamente gli account esterni per la condivisione federata.",
    "Server url" : "URL server",
    "Add" : "Aggiungi",
    "Delete" : "Elimina",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La federazione consente di connettersi ad altri server attendibili per scambiare la directory degli account. Ad esempio, questo verrà utilizzato per completare automaticamente gli account esterni per la condivisione federata. Non è necessario aggiungere un server come server attendibile per creare una condivisione federata.",
    "Each server must validate the other. This process may require a few cron cycles." : "Ogni server deve validare gli altri. Questa operazione può richiedere qualche ciclo cron.",
    "External documentation for Federated Cloud Sharing" : "Documentazione esterna per la Condivisione Federata",
    "+ Add trusted server" : "+ Aggiungi server affidabile",
    "Trusted server" : "Server affidabile"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
